;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "copilot-chat" "20251016.754"
  "Copilot chat interface."
  '((emacs         "29.1")
    (aio           "1.0")
    (request       "0.3.2")
    (transient     "0.8.3")
    (polymode      "0.2.2")
    (org           "9.4.6")
    (markdown-mode "2.6")
    (shell-maker   "0.76.2")
    (mcp           "0.1.0"))
  :url "https://github.com/chep/copilot-chat.el"
  :commit "24719dbc3f68e8c467b678edda48b7cf64b30360"
  :revdesc "24719dbc3f68"
  :keywords '("convenience" "tools")
  :authors '(("cedric.chepied" . "cedric.chepied@gmail.com"))
  :maintainers '(("cedric.chepied" . "cedric.chepied@gmail.com")))
